==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/ReportcategoryCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Reportcategory;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ReportcategoryRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class ReportcategoryCollectionRequest extends CollectionPageEntityRequest<Reportcategory, ReportcategoryRequest>{

    protected ContextPath contextPath;

    public ReportcategoryCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Reportcategory.class, cp -> new ReportcategoryRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public PrincipalobjectattributeaccessCollectionRequest reportcategory_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("reportcategory_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest reportcategory_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("reportcategory_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest reportCategory_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("ReportCategory_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest reportCategory_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ReportCategory_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/ReportcategoryCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Reportcategory;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ReportcategoryRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class ReportcategoryCollectionRequest extends CollectionPageEntityRequest<Reportcategory, ReportcategoryRequest>{

    protected ContextPath contextPath;

    public ReportcategoryCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Reportcategory.class, cp -> new ReportcategoryRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public PrincipalobjectattributeaccessCollectionRequest reportcategory_principalobjectattributeaccess() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("reportcategory_principalobjectattributeaccess"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest reportcategory_principalobjectattributeaccess(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("reportcategory_principalobjectattributeaccess").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest reportCategory_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("ReportCategory_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest reportCategory_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ReportCategory_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

}
